/*
 * XMLNewsParser.java
 *
 * Created on February 28, 2002, 8:11 AM
 */
import java.util.Enumeration;
/**
 * Interface for an XMLNewsParser.  Classes that implement this interface can
 * implement the xml parsing in any way they want (i.e. event based or DOM based).
 *
 * @author  andrewm
 * @version
 */
public interface XMLNewsParser
{
    /**
     * This method should be called to parse an XML news document
     *
     * @return boolean Returns true if the parsing completes without error
     */
    public boolean parse();
    
    /**
     * This method is used to retrieve XML news articles from the parsed
     * XML document and return them as an Enumeration of XMLNewsArticle objects
     *
     * @param int Maximum number of articles to return
     * @return Enumeration Enumeration of XMLNewsArticles
     */
    public Enumeration getXMLNewsArticles( int maxArticles );
    
    
    /**
     * This method should return the number of news articles that was in the XML
     * document that was parsed
     *
     * @return int Number of news articles in the xml news document
     */
    public int getNumArticles();
}

